@@ -18,3 +18,12 @@ test_that("Chi-squared approximation issues",{
         gives_warning("Chi-squared approximation is not suitable because expected frequency approximates to zero"))
         })
 
+context("Degree of Freedom")
+test_that("Degree of freedom less than zero",{
+        expect_that(fitBin(1,2),
+        gives_warning("Degrees of freedom cannot be less than or equal to zero"))
+        })
+test_that("Degree of freedom equal to zero",{
+        expect_that(fitBin(c(0,1),c(11,12)),
+        gives_warning("Degrees of freedom cannot be less than or equal to zero"))
+        })
