@@ -21,3 +21,13 @@ test_that("Chi-squared approximation issues",{
           expect_that(fitKumBin(0:4,c(2,5,1,4,3),1.1,1.0,10000),
           gives_warning("Chi-squared approximation may be doubtful because expected frequency is less than 5"))
           })
+
+context("Degree of Freedom")
+test_that("Degree of freedom less than zero",{
+          expect_that(fitKumBin(c(1,2),c(17,11),5.1,1.3,10000),
+          gives_warning("Degrees of freedom cannot be less than or equal to zero"))
+          })
+test_that("Degree of freedom equal to zero",{
+          expect_that(fitKumBin(c(0,1,2),c(11,12,12),1.1,1.3,10000),
+          gives_warning("Degrees of freedom cannot be less than or equal to zero"))
+          })
